Module columns

Module columns 

Structs

ByteMultCols
For each byte operation in the preprocessed table, a corresponding ByteMultCols row tracks the number of times the operation is used.
BytePreprocessedCols

Constants

NUM_BYTE_MULT_COLS
The number of multiplicity columns for ByteChip.
NUM_BYTE_PREPROCESSED_COLS
The number of main trace columns for ByteChip.