#[repr(C)]pub struct BranchColumns<T> {Show 19 fields
pub pc: Word<T>,
pub pc_range_checker: BabyBearWordRangeChecker<T>,
pub next_pc: Word<T>,
pub next_pc_range_checker: BabyBearWordRangeChecker<T>,
pub op_a_value: Word<T>,
pub op_b_value: Word<T>,
pub op_c_value: Word<T>,
pub op_a_0: T,
pub is_beq: T,
pub is_bne: T,
pub is_blt: T,
pub is_bge: T,
pub is_bltu: T,
pub is_bgeu: T,
pub is_branching: T,
pub not_branching: T,
pub a_eq_b: T,
pub a_gt_b: T,
pub a_lt_b: T,
}Expand description
The column layout for branching.
Fields
pc: Word<T>The current program counter.
pc_range_checker: BabyBearWordRangeChecker<T>next_pc: Word<T>The next program counter.
next_pc_range_checker: BabyBearWordRangeChecker<T>op_a_value: Word<T>The value of the first operand.
op_b_value: Word<T>The value of the second operand.
op_c_value: Word<T>The value of the third operand.
op_a_0: TWhether the first operand is register 0.
is_beq: TBranch Instructions.
is_bne: Tis_blt: Tis_bge: Tis_bltu: Tis_bgeu: Tis_branching: TThe is_branching column is equal to:
is_beq & a_eq_b || is_bne & (a_lt_b | a_gt_b) || (is_blt | is_bltu) & a_lt_b || (is_bge | is_bgeu) & (a_eq_b | a_gt_b)
not_branching: TThe not branching column is equal to:
is_beq & !a_eq_b || is_bne & !(a_lt_b | a_gt_b) || (is_blt | is_bltu) & !a_lt_b || (is_bge | is_bgeu) & !(a_eq_b | a_gt_b)
Note that we probably can do away with this column and just use !is_branching. However, the branching related constraints were auditted twice when they were part of the CPU table, so I’m preserving those columns/constraints for now.
a_eq_b: TWhether a equals b.
a_gt_b: TWhether a is greater than b.
a_lt_b: TWhether a is less than b.