#[repr(C)]pub struct CpuCols<T: Copy> {Show 17 fields
pub shard: T,
pub clk_16bit_limb: T,
pub clk_8bit_limb: T,
pub shard_to_send: T,
pub clk_to_send: T,
pub pc: T,
pub next_pc: T,
pub instruction: InstructionCols<T>,
pub op_a_immutable: T,
pub is_memory: T,
pub is_syscall: T,
pub is_halt: T,
pub num_extra_cycles: T,
pub op_a_access: MemoryReadWriteCols<T>,
pub op_b_access: MemoryReadCols<T>,
pub op_c_access: MemoryReadCols<T>,
pub is_real: T,
}Expand description
The column layout for the CPU.
Fields
shard: TThe current shard.
clk_16bit_limb: TThe least significant 16 bit limb of clk.
clk_8bit_limb: TThe most significant 8 bit limb of clk.
shard_to_send: TThe shard to send to the opcode specific tables. This should be 0 for all instructions other than the ecall and memory instructions.
clk_to_send: TThe clk to send to the opcode specific tables. This should be 0 for all instructions other than the ecall and memory instructions.
pc: TThe program counter value.
next_pc: TThe expected next program counter value.
instruction: InstructionCols<T>Columns related to the instruction.
op_a_immutable: TWhether op_a should not be changed by the instruction. This should be true for memory store and branch instructions.
is_memory: TWhether this is a memory instruction.
is_syscall: TWhether this is a syscall instruction.
is_halt: TWhether this is a halt instruction.
num_extra_cycles: TThe number of extra cycles to add to the clk for a syscall instruction.
op_a_access: MemoryReadWriteCols<T>Operand values, either from registers or immediate values.
op_b_access: MemoryReadCols<T>op_c_access: MemoryReadCols<T>is_real: TSelector to label whether this row is a non padded row.
Implementations