trace_chunk

Function trace_chunk 

pub fn trace_chunk<F: PrimeField32>(
    program: Arc<Program>,
    opts: SP1CoreOpts,
    chunk: impl MinimalTrace,
    proof_nonce: [u32; 4],
    record: ExecutionRecord,
) -> Result<(bool, ExecutionRecord, [MemoryRecord; 32]), ExecutionError>
Trace a single MinimalTrace (corresponding to a shard) and return the execution record.

This is the core tracing function that converts a minimal trace into a full execution record with all the events needed for proving.