#[repr(C)]pub struct MemoryInitCols<T: Copy> {Show 14 fields
pub clk_high: T,
pub clk_low: T,
pub index: T,
pub prev_addr: [T; 3],
pub addr: [T; 3],
pub lt_cols: LtOperationUnsigned<T>,
pub value: Word<T>,
pub value_lower: T,
pub value_upper: T,
pub is_real: T,
pub is_comp: T,
pub prev_valid: T,
pub is_prev_addr_zero: IsZeroOperation<T>,
pub is_index_zero: IsZeroOperation<T>,
}Fields
clk_high: TThe top bits of the timestamp of the memory access.
clk_low: TThe low bits of the timestamp of the memory access.
index: TThe index of the memory access.
prev_addr: [T; 3]The address of the previous memory access.
addr: [T; 3]The address of the memory access.
lt_cols: LtOperationUnsigned<T>Comparison assertions for address to be strictly increasing.
value: Word<T>The value of the memory access.
value_lower: TLower half of third limb of the value
value_upper: TUpper half of third limb of the value
is_real: TWhether the memory access is a real access.
is_comp: TWhether or not we are making the assertion prev_addr < addr.
prev_valid: TThe validity of previous state. The unique invalid state is when the chip only initializes address 0 once.
is_prev_addr_zero: IsZeroOperation<T>A witness to assert whether or not prev_addr is zero.
is_index_zero: IsZeroOperation<T>A witness to assert whether or not the index is zero.