#[repr(C)]pub struct RegisterAccessTimestamp<T> {
pub prev_low: T,
pub diff_low_limb: T,
}Expand description
Register Access Timestamp. The register accesses use the same argument as the memory accesses,
and shares the same space as the memory. This structure is used for register accesses in RISC-V.
For optimization, we ensure that all register accesses have the high limb of the timestamp and
previous timestamp to be equal. This is done through adding in a “shadow” read, through the
MemoryBump chip. Therefore, only the columns for low limb comparison is needed here.
Fields
prev_low: TThe previous timestamp that this memory access is being read from.
diff_low_limb: TThe difference in timestamp’s least significant 16 bit limb.
Implementations
Sourceimpl<F: PrimeField32> RegisterAccessTimestamp<F>
impl<F: PrimeField32> RegisterAccessTimestamp<F>
pub fn populate_timestamp( &mut self, prev_timestamp: u64, current_timestamp: u64, output: &mut impl ByteRecord, )