#[repr(C)]pub struct GlobalInteractionOperation<T: Copy> {
pub offset_bits: [T; 8],
pub x_coordinate: SepticBlock<T>,
pub y_coordinate: SepticBlock<T>,
pub y6_bit_decomp: [T; 30],
pub range_check_witness: T,
pub permutation: Poseidon2Operation<T>,
}Expand description
A set of columns needed to compute the global interaction elliptic curve digest.
Fields
offset_bits: [T; 8]x_coordinate: SepticBlock<T>y_coordinate: SepticBlock<T>y6_bit_decomp: [T; 30]range_check_witness: Tpermutation: Poseidon2Operation<T>Implementations
Sourceimpl<F: PrimeField32> GlobalInteractionOperation<F>
impl<F: PrimeField32> GlobalInteractionOperation<F>
pub fn get_digest( values: SepticBlock<u32>, is_receive: bool, kind: u8, ) -> (SepticCurve<F>, u8, [F; 16], [F; 16])
pub fn populate( &mut self, values: SepticBlock<u32>, is_receive: bool, is_real: bool, kind: u8, )
pub fn populate_dummy(&mut self)
Sourceimpl<F: Field> GlobalInteractionOperation<F>
impl<F: Field> GlobalInteractionOperation<F>
Sourcepub fn eval_single_digest<AB: SP1AirBuilder + PairBuilder>(
builder: &mut AB,
values: [AB::Expr; 7],
cols: GlobalInteractionOperation<AB::Var>,
is_receive: AB::Expr,
is_send: AB::Expr,
is_real: AB::Var,
kind: AB::Var,
)
pub fn eval_single_digest<AB: SP1AirBuilder + PairBuilder>( builder: &mut AB, values: [AB::Expr; 7], cols: GlobalInteractionOperation<AB::Var>, is_receive: AB::Expr, is_send: AB::Expr, is_real: AB::Var, kind: AB::Var, )
Constrain that the elliptic curve point for the global interaction is correctly derived.