#[repr(C)]pub struct SubwOperation<T> {
pub value: [T; 2],
pub msb: U16MSBOperation<T>,
}Expand description
A set of columns needed to compute the sub of two words.
Fields
value: [T; 2]The result of a - b.
msb: U16MSBOperation<T>The msb of the result.
Implementations
Sourceimpl<F: Field> SubwOperation<F>
impl<F: Field> SubwOperation<F>
pub fn populate(&mut self, record: &mut impl ByteRecord, a_u64: u64, b_u64: u64)
Sourcepub fn eval<AB>(
builder: &mut AB,
a: Word<AB::Var>,
b: Word<AB::Var>,
cols: SubwOperation<AB::Var>,
is_real: AB::Expr,
)
pub fn eval<AB>( builder: &mut AB, a: Word<AB::Var>, b: Word<AB::Var>, cols: SubwOperation<AB::Var>, is_real: AB::Expr, )
Evaluate the sub operation.
Assumes that a, b are valid Words of u16 limbs.
Constrains that is_real is boolean.
If is_real is true, the value is constrained to be the lower u32 of the SUBW result.
Also, the msb will be constrained to equal the most significant bit of the value.