#[repr(C)]pub struct SyscallInstrColumns<T, M: TrustMode> {Show 17 fields
pub state: CPUState<T>,
pub adapter: RTypeReader<T>,
pub next_pc: [T; 3],
pub is_halt: T,
pub op_a_value: Word<T>,
pub a_low_bytes: U16toU8Operation<T>,
pub is_enter_unconstrained: IsZeroOperation<T>,
pub is_hint_len: IsZeroOperation<T>,
pub is_halt_check: IsZeroOperation<T>,
pub is_commit: IsZeroOperation<T>,
pub is_commit_deferred_proofs: IsZeroOperation<T>,
pub index_bitmap: [T; 8],
pub expected_public_values_digest: [T; 4],
pub op_b_range_check: SP1FieldWordRangeChecker<T>,
pub op_c_range_check: SP1FieldWordRangeChecker<T>,
pub is_real: T,
pub user_mode_cols: M::SyscallInstrCols<T>,
}Fields
state: CPUState<T>The current shard, timestamp, program counter of the CPU.
adapter: RTypeReader<T>The adapter to read program and register information.
next_pc: [T; 3]The next program counter.
is_halt: TWhether the current instruction is a halt instruction. This is verified by the is_halt_check operation.
op_a_value: Word<T>The result of register op_a.
a_low_bytes: U16toU8Operation<T>Lower byte of two limbs of b.
is_enter_unconstrained: IsZeroOperation<T>Whether the current ecall is ENTER_UNCONSTRAINED.
is_hint_len: IsZeroOperation<T>Whether the current ecall is HINT_LEN.
is_halt_check: IsZeroOperation<T>Whether the current ecall is HALT.
is_commit: IsZeroOperation<T>Whether the current ecall is a COMMIT.
is_commit_deferred_proofs: IsZeroOperation<T>Whether the current ecall is a COMMIT_DEFERRED_PROOFS.
index_bitmap: [T; 8]Field to store the word index passed into the COMMIT ecall.
index_bitmap[word index] should be set to 1 and everything else set to 0.
expected_public_values_digest: [T; 4]The expected public values digest.
op_b_range_check: SP1FieldWordRangeChecker<T>The check if op_b is a valid SP1Field.
op_c_range_check: SP1FieldWordRangeChecker<T>The check if op_c is a valid SP1Field.
is_real: TWhether the current instruction is a real instruction.
user_mode_cols: M::SyscallInstrCols<T>Columns for handling syscall instructions in user mode.