Module utils

Module utils 

Modules

concurrency

Structs

MinimalAddChip
A chip that implements addition for the opcode ADDI.
MinimalAddCols
The column layout for the chip.
Span
A span for counting items in a recursive structure. Create and populate using SpanBuilder. S is the type of span names and T is the type of item names.
SpanBuilder
A builder to create a Span. S is the type of span names and T is the type of item names.

Enums

SP1CoreProverError
SpanBuilderError
SpanBuilderExitError
SpanBuilderFinishError

Constants

NUM_MINIMAL_ADD_COLS
The number of main trace columns for AddiChip.

Functions

bytes_to_words_le
Converts a byte array in little endian to a slice of words.
bytes_to_words_le_vec
Converts a byte array in little endian to a vector of words.
emit_globals
Postprocess into an existing ExecutionRecord, consisting of all the MemoryInitializeFinalizeEvents.
generate_records
Generate execution records from a program and inputs.
get_hint_event_addrs
Get set of addresses that were hinted.
indices_arr
Get an array xs such that xs[i] = i.
limbs_to_words
log2_strict_usize
next_multiple_of_32
Returns the internal value of the option if it is set, otherwise returns the next multiple of 32.
num_to_comma_separated
pad_rows_fixed
Pad to the next multiple of 32, with an option to specify the fixed height.
prove_core
Prove a program with the given inputs using SimpleProver.
reverse_slice_index_bits
Reverse the order of elements in a slice using bit-reversed indices.
setup_logger
A simple logger.
u32_to_half_word
words_to_bytes_le
Converts a slice of words to a slice of bytes in little endian.
words_to_bytes_le_vec
Converts a slice of words to a byte vector in little endian.
zeroed_f_vec
Returns a vector of zeros of the given length. This is faster than vec![F::zero(); len] which requires copying.