reverse_slice_index_bits

Function reverse_slice_index_bits 

pub fn reverse_slice_index_bits<T>(slice: &mut [T])
Reverse the order of elements in a slice using bit-reversed indices.

This function reorders the elements of a slice such that the element at index i is moved to index reverse_bits_len(i, log2(len)).