Module memory

Module memory 

Modules

air
columns
trace

Structs

MemoryAccessCols
MemoryGlobalChip
A memory chip that can initialize or finalize values in memory.
MemoryInitCols
MemoryInstructionsChip
MemoryLocalChip
MemoryLocalCols
MemoryProgramChip
Chip that initializes memory that is provided from the program. The table is preprocessed and receives each row in the first shard. This prevents any of these addresses from being overwritten through the normal MemoryInit.
MemoryProgramMultCols
Multiplicity columns.
MemoryProgramPreprocessedCols
The column layout for the chip.
MemoryReadCols
Memory read access.
MemoryReadWriteCols
Memory read-write access.
MemoryWriteCols
Memory write access.
SingleMemoryLocal

Enums

MemoryChipType
The type of global/local memory chip that is being initialized.

Constants

NUM_LOCAL_MEMORY_ENTRIES_PER_ROW
NUM_MEMORY_PROGRAM_MULT_COLS
NUM_MEMORY_PROGRAM_PREPROCESSED_COLS

Traits

MemoryCols
The common columns for all memory access types.

Functions

value_as_limbs
A utility method to convert a slice of memory access columns into a vector of values. This is useful for comparing the values of a memory access to limbs.