Modules
Structs
- Memory
Access Cols - Memory
Global Chip - A memory chip that can initialize or finalize values in memory.
- Memory
Init Cols - Memory
Instructions Chip - Memory
Local Chip - Memory
Local Cols - Memory
Program Chip - Chip that initializes memory that is provided from the program. The table is preprocessed and receives each row in the first shard. This prevents any of these addresses from being overwritten through the normal MemoryInit.
- Memory
Program Mult Cols - Multiplicity columns.
- Memory
Program Preprocessed Cols - The column layout for the chip.
- Memory
Read Cols - Memory read access.
- Memory
Read Write Cols - Memory read-write access.
- Memory
Write Cols - Memory write access.
- Single
Memory Local
Enums
- Memory
Chip Type - The type of global/local memory chip that is being initialized.
Constants
Traits
- Memory
Cols - The common columns for all memory access types.
Functions
- value_
as_ limbs - A utility method to convert a slice of memory access columns into a vector of values. This is useful for comparing the values of a memory access to limbs.