#[repr(C)]pub struct MemoryAccessTimestamp<T> {
pub prev_high: T,
pub prev_low: T,
pub compare_low: T,
pub diff_low_limb: T,
pub diff_high_limb: T,
}Expand description
Memory Access Timestamp
Fields
prev_high: TThe previous timestamp’s high 24 bits that this memory access is being read from.
prev_low: TThe previous timestamp’s low 24 bits that this memory access is being read from.
compare_low: TThis will be true if the top 24 bits do not match.
diff_low_limb: TThe following columns are decomposed limbs for the difference between the current access’s timestamp and the previous access’s timestamp. Note the actual value of the timestamp is either the accesses’ high or low 24 bits depending on the value of compare_low.
This column is the least significant 16 bit limb of the difference.
diff_high_limb: TThis column is the most significant 8 bit limb of the difference.
Implementations
Sourceimpl<F: PrimeField32> MemoryAccessTimestamp<F>
impl<F: PrimeField32> MemoryAccessTimestamp<F>
pub fn populate_timestamp( &mut self, prev_timestamp: u64, current_timestamp: u64, output: &mut impl ByteRecord, )