#[repr(C)]pub struct SyscallInstrColumns<T> {Show 19 fields
pub pc: T,
pub next_pc: T,
pub shard: T,
pub clk: T,
pub num_extra_cycles: T,
pub is_halt: T,
pub op_a_access: MemoryReadWriteCols<T>,
pub op_b_value: Word<T>,
pub op_c_value: Word<T>,
pub is_enter_unconstrained: IsZeroOperation<T>,
pub is_hint_len: IsZeroOperation<T>,
pub is_halt_check: IsZeroOperation<T>,
pub is_commit: IsZeroOperation<T>,
pub is_commit_deferred_proofs: IsZeroOperation<T>,
pub index_bitmap: [T; 8],
pub operand_range_check_cols: BabyBearWordRangeChecker<T>,
pub operand_to_check: Word<T>,
pub ecall_range_check_operand: T,
pub is_real: T,
}Fields
pc: TThe program counter of the instruction.
next_pc: TThe next program counter.
shard: TThe shard number.
clk: TThe clock cycle number.
num_extra_cycles: TThe number of extra cycles to add to the clk for a syscall instruction.
is_halt: TWhether the current instruction is a halt instruction. This is verified by the is_halt_check operation.
op_a_access: MemoryReadWriteCols<T>The access columns for the first operand.
op_b_value: Word<T>The value of the second operand.
op_c_value: Word<T>The value of the third operand.
is_enter_unconstrained: IsZeroOperation<T>Whether the current ecall is ENTER_UNCONSTRAINED.
is_hint_len: IsZeroOperation<T>Whether the current ecall is HINT_LEN.
is_halt_check: IsZeroOperation<T>Whether the current ecall is HALT.
is_commit: IsZeroOperation<T>Whether the current ecall is a COMMIT.
is_commit_deferred_proofs: IsZeroOperation<T>Whether the current ecall is a COMMIT_DEFERRED_PROOFS.
index_bitmap: [T; 8]Field to store the word index passed into the COMMIT ecall. index_bitmap[word index] should be set to 1 and everything else set to 0.
operand_range_check_cols: BabyBearWordRangeChecker<T>Columns to babybear range check the halt/commit_deferred_proofs operand.
operand_to_check: Word<T>The operand value to babybear range check.
ecall_range_check_operand: TThe result of is_real * (is_halt || is_commit_deferred_proofs)
is_real: TWhether the current instruction is a real instruction.