Modules
Structs
- Minimal
AddChip - A chip that implements addition for the opcode ADDI.
- Minimal
AddCols - The column layout for the chip.
- Span
- A span for counting items in a recursive structure. Create and populate using
SpanBuilder.Sis the type of span names andTis the type of item names. - Span
Builder - A builder to create a
Span.Sis the type of span names andTis the type of item names.
Enums
Constants
- NUM_
MINIMAL_ ADD_ COLS - The number of main trace columns for
AddiChip.
Functions
- bytes_
to_ words_ le - Converts a byte array in little endian to a slice of words.
- bytes_
to_ words_ le_ vec - Converts a byte array in little endian to a vector of words.
- emit_
globals - Postprocess into an existing
ExecutionRecord, consisting of all theMemoryInitializeFinalizeEvents. - generate_
records - Generate execution records from a program and inputs.
- get_
hint_ event_ addrs - Get set of addresses that were hinted.
- indices_
arr - Get an array
xssuch thatxs[i] = i. - limbs_
to_ words - log2_
strict_ usize - next_
multiple_ of_ 32 - Returns the internal value of the option if it is set, otherwise returns the next multiple of 32.
- num_
to_ comma_ separated - pad_
rows_ fixed - Pad to the next multiple of 32, with an option to specify the fixed height.
- prove_
core - Prove a program with the given inputs using SimpleProver.
- reverse_
slice_ index_ bits - Reverse the order of elements in a slice using bit-reversed indices.
- setup_
logger - A simple logger.
- u32_
to_ half_ word - words_
to_ bytes_ le - Converts a slice of words to a slice of bytes in little endian.
- words_
to_ bytes_ le_ vec - Converts a slice of words to a byte vector in little endian.
- zeroed_
f_ vec - Returns a vector of zeros of the given length. This is faster than vec![F::zero(); len] which requires copying.