Module utils

Module utils 

Re-exports

pub use uni_stark::*;

Modules

concurrency
uni_stark

Structs

Span
A span for counting items in a recursive structure. Create and populate using SpanBuilder. S is the type of span names and T is the type of item names.
SpanBuilder
A builder to create a Span. S is the type of span names and T is the type of item names.

Enums

SP1CoreProverError
SpanBuilderError
SpanBuilderExitError
SpanBuilderFinishError

Functions

bytes_to_words_le
Converts a byte array in little endian to a slice of words.
bytes_to_words_le_vec
Converts a byte array in little endian to a vector of words.
chunk_vec
indices_arr
limbs_from_access
limbs_from_prev_access
log2_strict_usize
next_power_of_two
Returns the next power of two that is >= n and >= 16. If fixed_power is set, it will return 2^fixed_power after checking that n <= 2^fixed_power.
num_to_comma_separated
pad_rows_fixed
Pad to a power of two, with an option to specify the power.
pad_to_power_of_two
par_for_each_row
prove_core
prove_core_stream
run_malicious_test
run_test
The canonical entry point for testing a Program and SP1Stdin with a MachineProver.
run_test_core
run_test_machine
run_test_machine_with_prover
setup_logger
A simple logger.
sp1_debug_mode
Returns whether the SP1_DEBUG environment variable is enabled or disabled.
trace_checkpoint
words_to_bytes_le
Converts a slice of words to a slice of bytes in little endian.
words_to_bytes_le_vec
Converts a slice of words to a byte vector in little endian.
zeroed_f_vec
Returns a vector of zeros of the given length. This is faster than vec![F::zero(); len] which requires copying.