Re-exports
pub use uni_stark::*;
Modules
Structs
- Span
- A span for counting items in a recursive structure. Create and populate using
SpanBuilder.Sis the type of span names andTis the type of item names. - Span
Builder - A builder to create a
Span.Sis the type of span names andTis the type of item names.
Enums
Functions
- bytes_
to_ words_ le - Converts a byte array in little endian to a slice of words.
- bytes_
to_ words_ le_ vec - Converts a byte array in little endian to a vector of words.
- chunk_
vec - indices_
arr - limbs_
from_ access - limbs_
from_ prev_ access - log2_
strict_ usize - next_
power_ of_ two - Returns the next power of two that is >=
nand >= 16. Iffixed_poweris set, it will return2^fixed_powerafter checking thatn <= 2^fixed_power. - num_
to_ comma_ separated - pad_
rows_ fixed - Pad to a power of two, with an option to specify the power.
- pad_
to_ power_ of_ two - par_
for_ each_ row - prove_
core - prove_
core_ stream - run_
malicious_ test - run_
test - The canonical entry point for testing a
ProgramandSP1Stdinwith aMachineProver. - run_
test_ core - run_
test_ machine - run_
test_ machine_ with_ prover - setup_
logger - A simple logger.
- sp1_
debug_ mode - Returns whether the
SP1_DEBUGenvironment variable is enabled or disabled. - trace_
checkpoint - words_
to_ bytes_ le - Converts a slice of words to a slice of bytes in little endian.
- words_
to_ bytes_ le_ vec - Converts a slice of words to a byte vector in little endian.
- zeroed_
f_ vec - Returns a vector of zeros of the given length. This is faster than vec![F::zero(); len] which requires copying.