pub fn sp1_debug_mode() -> boolExpand description
Returns whether the SP1_DEBUG environment variable is enabled or disabled.
This variable controls whether backtraces are attached to compiled circuit programs, as well as whether cycle tracking is performed for circuit programs.
By default, the variable is disabled.